require 'berkshelf/notifiers/datadog/version'

module Berkshelf
  module Notifiers
    module Datadog
      require 'dogapi'

      # Output a Cookbook upload message using {Berkshelf.ui}
      # Send Datadog an event using {Dogapi}
      #
      # @param [Berkshelf::CachedCookbook] cookbook
      # @param [Ridley::Connection] conn
      def uploaded(cookbook, conn)
        upload_message = "Uploaded #{cookbook.cookbook_name} (#{cookbook.version}) to: '#{conn.server_url}'"

        # Invoke the original method declaration
        super

        # Only attempt to talk to Datadog if we have an env var set
        api_key = ENV['DATADOG_API_KEY']

        if api_key
          Berkshelf.ui.info "Sending a Datadog event for #{cookbook.cookbook_name} (#{cookbook.version})"

          dog = Dogapi::Client.new(api_key)

          dog.emit_event(
            Dogapi::Event.new(
              upload_message,
              msg_title: "Berkshelf uploaded #{cookbook.cookbook_name} v#{cookbook.version}",
              tags: [
                'berkshelf',
                "cookbook:#{cookbook.cookbook_name}",
              ]
            )
          )
        else
          Berkshelf.ui.info 'No Datadog API key provided, skipping'
        end
      end
    end
  end
end

# README: Cleanly monkey patch default formatter for Berkshelf
#
# See https://stackoverflow.com/a/4471202/133479
module Berkshelf
  class HumanFormatter
    prepend Berkshelf::Notifiers::Datadog
  end
end
